%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Counterfactual of Shifting the Composition of the Market
%Written by Garrett Senney
%Updated on March 29, 2017
%User-required Inputs: prices, NP, CF (Original = 1, High = 2, Low =3), and R (Max = 1, Mean = 2, Min = 3)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%Calculate the composition of each type of firm in each period
Comp = zeros(NP,3);
NoPrices = zeros(NP,1);
for j=1:NP
    PR = [];
    PR = prices{1,j};
    L = 0;
    M = 0;
    H = 0;
    for i=1:size(PR,1)
        if PR(i,1)<2
            L=L+1;
        elseif PR(i,1)<3
            M=M+1;
        else
            H=H+1;
        end
    end
    Comp(j,:) = [L,M,H]/size(PR,1);
    NoPrices(j,:) = size(PR,1);
end

%Subset the prices by firm type and pool across periods
p = [];

for i=1:NP
    p = [p;i*ones(NoPrices(i),1),prices{1,i}];
end

Lp = [];
Mp = [];
Hp = [];
Lp = find(p(:,2)==1);
Mp = find(p(:,2)==2);
Hp = find(p(:,2)==3);

Hmax = [];
Mmax = [];
Lmax = [];
Hmean = [];
Mmean = [];
Lmean = [];
Hmax = max(p(Hp,3));
Mmax = max(p(Mp,3));
Lmax = max(p(Lp,3));
Hmean = mean(p(Hp,3));
Mmean = mean(p(Mp,3));
Lmean = mean(p(Lp,3));
Hmin = min(p(Hp,3));
Mmin = min(p(Mp,3));
Lmin = min(p(Lp,3));


%%

if CF == 1
   %Normal prices with no changes
    PRICES = prices;
   
elseif CF == 2
%CF1: Increase the number of High quality firms 
        rng(1117)
        PRICES = [];

        for j=1:NP
            PR = [];
            PR = prices{1,j};
            a = [];
            c = [];
            e = [];
            a = find(PR==1);
            c = find(PR==2);
            e = find(PR==3);
            L = [];
            M = [];
            H = [];
            L = PR(a,2);
            M = PR(c,2);
            H = PR(e,2);
            if R==1
                   %Add 5 max priced H firms to this market
                   H = [H;(Hmax+2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            elseif R==2
                   %Add 5 avg priced H firms to this market
                   H = [H;(Hmean+2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            else
                   %Add 5 min priced H firms to this market
                   H = [H;(Hmin-2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            end
            P = [];
            P = [ones(size(L)),L;
                 2*ones(size(M)),M;
                 3*ones(size(H)),H];
    
            PRICES{j} = P;
        end
else
%1.2: Increase the number of Low quality firms
   rng(1117)
   PRICES = [];

   for j=1:NP
       PR = [];
       PR = prices{1,j};
       a = [];
       c = [];
       e = [];
       a = find(PR==1);
       c = find(PR==2);
       e = find(PR==3);
            L = [];
            M = [];
            H = [];
            L = PR(a,2);
            M = PR(c,2);
            H = PR(e,2);
    
            if R==1
                   %Add 5 max priced H firms to this market
                   L = [L;(Lmax+2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            elseif R==2
                   %Add 5 avg priced H firms to this market
                   L = [L;(Lmean+2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            else
                   %Add 5 min priced H firms to this market
                   L = [L;(Hmin-2.*((-1).^(rand(5,1)<.5)).*rand(5,1))];
            end
            
            P = [];
            P = [ones(size(L)),L;
                2*ones(size(M)),M;
                3*ones(size(H)),H];
    
            PRICES{j} = P;
        end
end   

