%Garrett Senney & Jason Blevins
%Dynamic Search Model for Multiple Periods
%Simulating Counterfactual Master Script
%Last Updated on May 13, 2017
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Initial Period Distribution (G_0) is set equal to the estimated Population Distribution (H) from the application section of the DCS paper
%User input: book
%%Book: Amemiya    Cameron
%                     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Global Condition
NP = 10000; %Number of periods
n = 1:1:(NP); %Counter
NA = 1000; %Number of agents in the market
shock=0:0.25:3;

% Set the random number generator seed for reproducibility
rng(1177, 'twister');
s = rng;

%Load parameter of H
if book == 'Amemiya'
     theta = 6.402;
     H_Mean = 6.402;
     H_Median = 6.402*log(2);
else
    theta = 6.309;
    H_Mean = 6.309;
    H_Median = 6.309*log(2);
end

if book == 'Amemiya'
      %Period = 35, median of G_35 is $10.1672, so mean of G_35(c|theta) is 10.1672/ln(2)= 14.6682
      %Period = 36, medin of G_36 is $11.8737, so mean of G_36(c|theta) is 11.8737/ln(2)= 17.1301
      SigTheta = 7.0014;
else
       %Period = 35, median of G_35 is $8.4513, so mean of G_35(c|theta) is 8.4513/ln(2)= 12.19264
       %Period = 36, median of G_36 is $8.2158, so mean of G_36(c|theta) is 8.2158/ln(2)= 11.8528
       SigTheta = 5.6744;
end
%SigTheta is the estimated parameter for the consumer purchased probability between t=35 and t=36 assuming sigma is exponentially distributed.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Start of Simulation
%%Truth
G_True_LongTerm = [];

Max_All = [];
Mean_All = [];
Median_All = [];
Min_All = [];

%Create G_0 = H
Y = [];
H_matrix = [];
Y = exprnd(theta,NA,1);
H_matrix = exprnd(theta,NA,1);

%Main simulation with consumer exit and entry
    for i=1:NP
        D = [];
        YT = [];
        D = (expcdf(Y(:),SigTheta)>rand(1)); 
        
        YT = D.*Y;
        idx = (YT==0);
        Y(idx) = H_matrix(idx);
     
        Max_All(:,i) = max(Y);
        Mean_All(:,i) = mean(Y);
        Median_All(:,i) = median(Y);
        Min_All(:,i) = min(Y);
    end

G_True_LongTerm = [Max_All(NP),Mean_All(NP),Median_All(NP),Min_All(NP)];

%True Theta Plus Some Amount

G_Pos_LongTerm = [];

 Max_All = [];
 Mean_All = [];
 Median_All = [];
 Min_All = [];
for fog=1:13
    rng(s);
    %Create G_0 = H
    Y = [];
    H_matrix = [];
    Y = exprnd(theta,NA,1);
    H_matrix = exprnd(theta+shock(fog),NA,1);
   
    for i=1:NP
        D = [];
        YT = [];
        D = (expcdf(Y(:),SigTheta)>rand(1)); 
        
        YT = D.*Y;
        idx = (YT==0);
        Y(idx) = H_matrix(idx);
     
        Max_All(:,i) = max(Y);
        Mean_All(:,i) = mean(Y);
        Median_All(:,i) = median(Y);
        Min_All(:,i) = min(Y);
    end

G_Pos_LongTerm(fog,:) = [Max_All(NP),Mean_All(NP),Median_All(NP),Min_All(NP)];
end


%%True Theta Minus Some Amount
G_Neg_LongTerm = [];

 Max_All = [];
 Mean_All = [];
 Median_All = [];
 Min_All = [];

for fog=1:13
    rng(s);
    %Create G_0 = H
    Y = [];
    H_matrix = [];
    Y = exprnd(theta,NA,1);
    H_matrix = exprnd(theta-shock(fog),NA,1);

    for i=1:NP
        D = [];
        YT = [];
        D = (expcdf(Y(:),SigTheta)>rand(1)); 

        YT = D.*Y;
        idx = (YT==0);
        Y(idx) = H_matrix(idx);
     
        Max_All(:,i) = max(Y);
        Mean_All(:,i) = mean(Y);
        Median_All(:,i) = median(Y);
        Min_All(:,i) = min(Y);
    end

G_Neg_LongTerm(fog,:) = [Max_All(NP),Mean_All(NP),Median_All(NP),Min_All(NP)];
end

%Table 7
delta = [0;0.5;1;2;3];
index = [1,3,5,9,13];
Table7 = [];
Table7 = [delta,(G_Pos_LongTerm(index,2)-H_Mean)./H_Mean,(G_Pos_LongTerm(index,3)-H_Median)./H_Median,(G_Neg_LongTerm(index,2)-H_Mean)./H_Mean,(G_Neg_LongTerm(index,3)-H_Median)./H_Median];

fname = sprintf('Simulation of Counterfactual for Book_%s- Sigma_%s.mat',book);
save(fname,'NP','NA','H_Mean','H_Median','G_Neg_LongTerm','G_Pos_LongTerm','G_True_LongTerm','Table7');


