% Jason R. Blevins and Garrett T. Senney
% Dynamic Selection and Distributional Bounds on Search Costs in Dynamic Unit-Demand Models
% Quantitative Economics
%
% Calculates the residuals used for non-linear least squares estimation

function [ resid ] = DCS_H_NLLS(k, NP, C_All, lb_H, ub_H, cdf, theta)

H_cp = zeros(NP-1,k);
for t = 1:NP-1
    cp = C_All(t+1,:);
    H_cp(t,2:k) = cdf(cp(2:k), theta);
end

resid_lb = (H_cp < lb_H) .* (lb_H - H_cp);
resid_ub = (H_cp > ub_H) .* (H_cp - ub_H);

nr = (NP-1)*k;
resid = [ reshape(resid_lb, nr, 1); reshape(resid_ub, nr, 1); ];
