% Jason R. Blevins and Garrett T. Senney
% Dynamic Selection and Distributional Bounds on Search Costs in Dynamic Unit-Demand Models
% Quantitative Economics
%
% Report quantiles of G_t via linear interpolation

periods = [ 25, 50, 75, 100, 125, 150, 175, 200, 225 ];
p_values = [ 0.01, 0.05, 0.25, 0.5, 0.75, 0.95, 0.99 ];
nquant = size(p_values, 2);
quantiles = zeros(NP, nquant);

% Calculate quantiles for all periods
for t = 1:NP
    [G_unique, ia, ic ] = unique(G_c_All(t,:), 'first');
    c_unique = C_All(t,ia);
    quantiles(t,:) = interp1(G_unique, c_unique, p_values);
end
meanquantiles = nanmean(quantiles);
medianquantiles = nanmedian(quantiles);

% Report a table of quantiles in selected periods
disp(sprintf('%s (k = %d):', book, k));
valfmt = repmat('%8.2f', [1, size(p_values, 2)]);
rowfmt = sprintf('%s%s', '%15s', valfmt);
disp(sprintf(rowfmt, 'Quantile', p_values));
rowfmt = sprintf('%s%s', '%10s%5d', valfmt);
for j = 1:size(periods, 2)
    t = periods(j);
    disp(sprintf(rowfmt, 't = ', t, quantiles(t,:)));
end
disp(sprintf(rowfmt, 'Mean', NP, meanquantiles));
disp(sprintf(rowfmt, 'Median', NP, medianquantiles));

% Boostrap: save p_values, quantiles.
