% Jason R. Blevins and Garrett T. Senney
% Dynamic Selection and Distributional Bounds on Search Costs in Dynamic Unit-Demand Models
% Quantitative Economics
%
% Report quantiles of H via linear interpolation of lower and upper cdf bounds

p_values = [ 0.01, 0.05, 0.25, 0.5, 0.75, 0.95, 0.99 ];

% Quantiles for lower bounds
[max_lb_H_unique, ia_lb, ic_lb ] = unique(max_lb_H, 'first');
c_H_lb = c_H(ia_lb);
c_lb = interp1(max_lb_H_unique, c_H_lb, p_values);

% Quantiles for upper bounds
[min_ub_H_unique, ia_ub, ic_ub ] = unique(min_ub_H, 'first');
c_H_ub = c_H(ia_ub);
c_ub = interp1(min_ub_H_unique, c_H_ub, p_values);

% Quantiles for average bound
[avg_lb_ub_unique, ia_avg, ic_avg ] = unique(avg_H, 'first');
c_H_avg = c_H(ia_avg);
c_avg = interp1(avg_lb_ub_unique, c_H_avg, p_values);

% Report results
disp(sprintf('%s (k = %d):', book, k));
valfmt = repmat('%8.2f', [1, size(p_values, 2)]);
rowfmt = sprintf('%s%s', '%15s', valfmt);
disp(sprintf(rowfmt, 'Quantile', p_values));
disp(sprintf(rowfmt, 'Lower bound', c_lb));
disp(sprintf(rowfmt, 'Upper bound', c_ub));
disp(sprintf(rowfmt, 'Average bound', c_avg));

% Boostrap: save p_values, c_lb, c_ub, c_avg.
