% Jason R. Blevins and Garrett T. Senney
% Dynamic Selection and Distributional Bounds on Search Costs in Dynamic Unit-Demand Models
% Quantitative Economics
%
% Prints a table of summary statistics

function [ Table2_P, Table2_U, TablePeriod_P, TablePeriod_U ] = DCS_SS( prices, utilities, NP )

    PRICES1 = [];
    PRICES2 = [];
    PRICES3 = [];
    Utilities1 = [];
    Utilities2 = [];
    Utilities3 = [];

    for i=1:NP
        indx1=(prices{i}(:,1)==1);
        PRICES1{i} =  prices{i}(indx1,2);
        Utilities1{i} = utilities{i}(indx1,2);

        indx2=(prices{i}(:,1)==2);
        PRICES2{i} =  prices{i}(indx2,2);
        Utilities2{i} = utilities{i}(indx2,2);

        indx3=(prices{i}(:,1)==3);
        PRICES3{i} =  prices{i}(indx3,2);
        Utilities3{i} = utilities{i}(indx3,2);
    end

    %%% Summery Statistics for prices and utility across all periods
    P = [];
    P1 = [];
    P2 = [];
    P3 = [];
    U = [];
    U1 = [];
    U2 = [];
    U3 =[];

    for i=1:NP
        P = [P;prices{i}(:,2)];
        P1 = [P1;PRICES1{i}];
        P2 = [P2;PRICES2{i}];
        P3 = [P3;PRICES3{i}];
        U = [U;utilities{i}(:,2)];
        U1 = [U1;Utilities1{i}];
        U2 = [U2;Utilities2{i}];
        U3 = [U3;Utilities3{i}];
    end

    %% All Retailers
    MAX_P(1,1) = max(P);
    MEDIAN_P(1,1) = median(P);
    MEAN_P(1,1) = mean(P);
    MIN_P(1,1) = min(P);
    STDDEV_P(1,1) = std(P);
    OBS_P(1,1) = size(P,1);

    MAX_U(1,1) = max(U);
    MEDIAN_U(1,1) = median(U);
    MEAN_U(1,1) = mean(U);
    MIN_U(1,1) = min(U);
    STDDEV_U(1,1) = std(U);
    OBS_U(1,1) = size(U,1);

    %% Non-verified Retailers
    MAX_P(1,2) = max(P1);
    MEDIAN_P(1,2) = median(P1);
    MEAN_P(1,2) = mean(P1);
    MIN_P(1,2) = min(P1);
    STDDEV_P(1,2) = std(P1);
    OBS_P(1,2) = size(P1,1);

    MAX_U(1,2) = max(U1);
    MEDIAN_U(1,2) = median(U1);
    MEAN_U(1,2) = mean(U1);
    MIN_U(1,2) = min(U1);
    STDDEV_U(1,2) = std(U1);
    OBS_U(1,2) = size(U1,1);

    %% Verified, Non-major Retailers
    MAX_P(1,3) = max(P2);
    MEDIAN_P(1,3) = median(P2);
    MEAN_P(1,3) = mean(P2);
    MIN_P(1,3) = min(P2);
    STDDEV_P(1,3) = std(P2);
    OBS_P(1,3) = size(P2,1);

    MAX_U(1,3) = max(U2);
    MEDIAN_U(1,3) = median(U2);
    MEAN_U(1,3) = mean(U2);
    MIN_U(1,3) = min(U2);
    STDDEV_U(1,3) = std(U2);
    OBS_U(1,3) = size(U2,1);

    %% Major Retailers
    MAX_P(1,4) = max(P3);
    MEDIAN_P(1,4) = median(P3);
    MEAN_P(1,4) = mean(P3);
    MIN_P(1,4) = min(P3);
    STDDEV_P(1,4) = std(P3);
    OBS_P(1,4) = size(P3,1);

    MAX_U(1,4) = max(U3);
    MEDIAN_U(1,4) = median(U3);
    MEAN_U(1,4) = mean(U3);
    MIN_U(1,4) = min(U3);
    STDDEV_U(1,4) = std(U3);
    OBS_U(1,4) = size(U3,1);

    %% Table 2 Creation
    Table2_P =[];
    Table2_U = [];
    Table2_P=[MIN_P;MAX_P;MEAN_P;MEDIAN_P;STDDEV_P;OBS_P];
    Table2_U=[MIN_U;MAX_U;MEAN_U;MEDIAN_U;STDDEV_U;OBS_U];

    %%% Summery Statistics for prices and utility within periods
    % Prices
    Max_P1 = [];
    Max_P2 = [];
    Max_P3 = [];
    Q75_P1 = [];
    Q75_P2 = [];
    Q75_P3 = [];
    Mean_P1 = [];
    Mean_P2 = [];
    Mean_P3 = [];
    Median_P1 = [];
    Median_P2 = [];
    Median_P3 = [];
    Q25_P1 = [];
    Q25_P2 = [];
    Q25_P3 = [];
    Min_P1 = [];
    Min_P2 = [];
    Min_P3 = [];

    Max_P13 = [];
    Q75_P13 = [];
    Mean_P13 = [];
    Medain_P13 = [];
    Q25_P13 = [];
    Min_P13 = [];

    for i=1:NP
        Max_P1(1,i) = max(PRICES1{i});
        Max_P2(1,i) = max(PRICES2{i});
        Max_P3(1,i) = max(PRICES3{i});
        
        Q75_P1(1,i) = quantile(PRICES1{i},0.75);
        Q75_P2(1,i) = quantile(PRICES2{i},0.75);
        Q75_P3(1,i) = quantile(PRICES3{i},0.75);
        
        Mean_P1(1,i) = mean(PRICES1{i});
        Mean_P2(1,i) = mean(PRICES2{i});
        Mean_P3(1,i) = mean(PRICES3{i}); 
        
        Median_P1(1,i) = median(PRICES1{i});
        Median_P2(1,i) = median(PRICES2{i});
        Median_P3(1,i) = median(PRICES3{i}); 
        
        Q25_P1(1,i) = quantile(PRICES1{i},0.25);
        Q25_P2(1,i) = quantile(PRICES2{i},0.25);
        Q25_P3(1,i) = quantile(PRICES3{i},0.25);
        
        Min_P1(1,i) = min(PRICES1{i});
        Min_P2(1,i) = min(PRICES2{i});
        Min_P3(1,i) = min(PRICES3{i});
        
    end

    Max_P13 = [Max_P1;Max_P2;Max_P3];
    Q75_P13 = [Q75_P1;Q75_P2;Q75_P3];
    Mean_P13 = [Mean_P1;Mean_P2;Mean_P3];
    Medain_P13 = [Median_P1;Median_P2;Median_P3];
    Q25_P13 = [Q25_P1;Q25_P2;Q25_P3];
    Min_P13 = [Min_P1;Min_P2;Min_P3];

    TablePeriod_P = {Max_P13, Q75_P13, Mean_P13, Medain_P13, Q25_P13, Min_P13};

    %Utilities
    Max_U1 = [];
    Max_U2 = [];
    Max_U3 = [];
    Q75_U1 = [];
    Q75_U2 = [];
    Q75_U3 = [];
    Mean_U1 = [];
    Mean_U2 = [];
    Mean_U3 = [];
    Median_U1 = [];
    Median_U2 = [];
    Median_U3 = [];
    Q25_U1 = [];
    Q25_U2 = [];
    Q25_U3 = [];
    Min_U1 = [];
    Min_U2 = [];
    Min_U3 = [];

    Max_U13 = [];
    Q75_U13 = [];
    Mean_U13 = [];
    Medain_U13 = [];
    Q25_U13 = [];
    Min_U13 = [];

    for i=1:NP
        Max_U1(1,i) = max(Utilities1{i});
        Max_U2(1,i) = max(Utilities2{i});
        Max_U3(1,i) = max(Utilities3{i});
        
        Q75_U1(1,i) = quantile(Utilities1{i},0.75);
        Q75_U2(1,i) = quantile(Utilities2{i},0.75);
        Q75_U3(1,i) = quantile(Utilities3{i},0.75);
        
        Mean_U1(1,i) = mean(Utilities1{i});
        Mean_U2(1,i) = mean(Utilities2{i});
        Mean_U3(1,i) = mean(Utilities3{i}); 
        
        Median_U1(1,i) = median(Utilities1{i});
        Median_U2(1,i) = median(Utilities2{i});
        Median_U3(1,i) = median(Utilities3{i}); 
        
        Q25_U1(1,i) = quantile(Utilities1{i},0.25);
        Q25_U2(1,i) = quantile(Utilities2{i},0.25);
        Q25_U3(1,i) = quantile(Utilities3{i},0.25);
        
        Min_U1(1,i) = min(Utilities1{i});
        Min_U2(1,i) = min(Utilities2{i});
        Min_U3(1,i) = min(Utilities3{i});
        
    end

    Max_U13 = [Max_U1;Max_U2;Max_U3];
    Q75_U13 = [Q75_U1;Q75_U2;Q75_U3];
    Mean_U13 = [Mean_U1;Mean_U2;Mean_U3];
    Medain_U13 = [Median_U1;Median_U2;Median_U3];
    Q25_U13 = [Q25_U1;Q25_U2;Q25_U3];
    Min_U13 = [Min_U1;Min_U2;Min_U3];

    TablePeriod_U = {Max_U13, Q75_U13, Mean_U13, Medain_U13, Q25_U13, Min_U13};

    % Print summary statistics
    format shortg;
    cols = [ 'All     ';
             'Non-Ver ';
             'Verified';
             'Major   '];
    rows = [ 'Min.    ';
             'Max.    ';
             'Mean    ';
             'Median  ';
             'St. Dev.';
             'Obs.    '];
    disp(sprintf('\nPrice Summary Statistics\n'));
    disp(sprintf('          %8s  %8s  %8s  %8s', cols(1,:), cols(2,:), cols(3,:), cols(4,:)));
    for i = 1:size(Table2_P, 1)
        disp(sprintf('%8s  %8.2f  %8.2f  %8.2f  %8.2f', rows(i,:), Table2_P(i,:)));
    end
    disp(sprintf('\nUtility Summary Statistics\n'));
    disp(sprintf('          %8s  %8s  %8s  %8s', cols(1,:), cols(2,:), cols(3,:), cols(4,:)));
    for i = 1:size(Table2_P, 1)
        disp(sprintf('%8s  %8.2f  %8.2f  %8.2f  %8.2f', rows(i,:), Table2_U(i,:)));
    end
    disp(sprintf('\n'));

end
