% Jason R. Blevins and Garrett T. Senney
% Dynamic Selection and Distributional Bounds on Search Costs in Dynamic Unit-Demand Models
% Quantitative Economics
%
% Transforms prices into utilities as in Wildenbeest (2011)

function [ utilities ] = DCS_utilities(prices)

NP = length(prices);

% Collect all prices for all periods in a matrix Pall with
% rows of the form [ period, type, price ].
P_all = [ ];
for t = 1:NP
    nprices = length(prices{t});
    P_t = [ t * ones(nprices, 1), prices{t} ];
    P_all = [ P_all; P_t ];
end

% Determine average prices by type and construct (negative) utility
% matrix
U_all = zeros(size(P_all));
U_all(:,1:2) = P_all(:,1:2);
for type = 1:3
    indx = ( P_all(:, 2) == type );
    P_type = P_all(indx, 3);
    U_all(indx, 3) = mean(P_type) - P_type;
end
U_all(:, 3) = U_all(:, 3) - min(U_all(:, 3));

% Reconstruct an array of (negative) utilities by period
utilities = {};
for t = 1:NP
    indx = ( U_all(:, 1) == t );
    utilities{t} = U_all(indx, 2:3);
end
