# Replication Files for QE-728

This archive contains the Matlab code used to produce the results in
the paper "Dynamic Selection and Distributional Bounds on Search Costs
in Dynamic Unit-Demand Models" by Jason R. Blevins and Garrett
T. Senney, which is to appear in _Quantitative Economics_.

## Estimation

Estimation of the main specifications, to produce the results in
Tables 1-4, starts with a series of simple control scripts:

* `Run_Amemiya_MGW_unrs.m`
* `Run_Amemiya_MGW_mono.m`
* `Run_Amemiya_W2011_unrs.m`
* `Run_Amemiya_W2011_mono.m`
* `Run_Cameron_MGW_unrs.m`
* `Run_Cameron_MGW_mono.m`
* `Run_Cameron_W2011_unrs.m`
* `Run_Cameron_W2011_mono.m`

`Amemiya` and `Cameron` refer to the two econometrics textbooks
studied in the application.  `MGW` and `W2011` refer to two estimators
used for the within-period search cost distributions: Moraga-González
and Wildenbeest (2008) and Wildenbeest (2011), the latter of which
controls for vertical differentiation of the booksellers.  Finally,
`unrs` and `mono` refer to the class of purchase policies considered:
unrestricted policies or only monotonic policies.

The data files used for the application are `Amemiya_Prices.mat` and
`Cameron_Prices.mat`.

The `Logs` directory contains the full log files containing the
results which are reported in the paper.

Each of the small control scripts above configures a few settings
(such as the number of replications and the type of estimator) and
then calls `Bootstrapping_Master.m`.  This script carries out the main
bootstrap loop and collects the results.  Each replication is
estimated using the script `Bootstrapping_Estimation`.

Other files used in estimation:

* `DCS_SS.m` prints a table of summary statistics (Table 1).
* `Precalculate_H_Bounds.m` precalculates lower and upper bounds on
  $H$ for each period and cutoff.
* `DCS_Master_NLS.m` carries out non-linear least squares estimation
  of the parameters of the population search cost distribution $H$.
* `DCS_Report_G_Quantiles.m` reports quantiles of the period serch
  cost distributions $G_t$ via linear interpolation.
* `DCS_Report_H_Quantiles.m` reports quantiles of the population
  search cost distribution $H$ via linear interpolation of lower and
  upper cdf bounds.
* `DCS_H_NLLS.m` calculates the residuals used for non-linear least
  squares estimation.
* `loglik.m`, `f.m`, `condc.m`, and `conddc.m` are used for estimating
  the period search cost distributions.  These files were originally
  written by Matthijs Wildenbeest and were generously shared with us
  for use in this paper.  Since the present code estimates search cost
  distributions for several periods at a time in parallel, we use
  modified versions of these files for thread safety.

## Simulation Exercise

The simulation study in Section 4 of the paper was carried out using
the `Selection_Bias_Master.m` and `Selection_Bias_Plots_Master.m`
control scripts in the `Simulations` directory.  Related files are:

* `Selection_Bias.m` carries out each simulation specification.
* `Selection_Bias_Plots.m` produces plots for each simulation specification.
* `Sigma_Fun.m` implements various functional forms for policy functions.

## Counterfactuals

The scripts used for each of the three counterfactuals reported in the
paper in sections 7.1, 7.2, and 7.3 are contained in the
subdirectories `Counterfactual 1`, `Counterfactual 2`, and
`Counterfactual 3` respectively.
