%Garrett Senney & Jason Blevins
%Dynamic Search Model for Multiple Periods
%Simulating Selection Bias Worker Script
%Last Updated on May 13, 2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%Initializing matrices for storage
Max_All = [];
Q3_All = [];
Mean_All = [];
Median_All = [];
Q1_All = [];
Min_All = [];

%Generate the starting distribution of G_{t}(c)
if strcmp(G_Dist,'Gamma')
   theta_g = [25,0.2];
   Y = gamrnd(theta_g(1),theta_g(2),NA,1);

elseif strcmp(G_Dist,'Lognormal')
       mu = 1.5;
       sigma = 1;
       Y = lognrnd(mu,sigma,NA,1);
       
 elseif strcmp(G_Dist,'Uniform')
        Y = 25*rand(NA,1);
 
else %Empirical CDF from last period of data (Amemiya)
    beta = [-2, 24];
    Y = beta(1)+beta(2)*rand(NA,1);
end

%Generate the entry distribution of H(c) 
  if strcmp(H_Dist,'Exponential') %Exponential distribution with estimated mean
     theta = 4.12676;
     H_Mean = 4.12676;
     H_Median = 4.12676*log(2);
     
  elseif strcmp(H_Dist,'Gamma') %Gamma distribution 
      theta = [25, 0.2];
      H_Mean = 5;
      H_Median = 4.9317;
      
  else  %Longnorm distribution
      mu = 1.5;
      sigma = 1;
      HDist = 'Lognormal';
      H_Mean = exp(2);
      H_Median = exp(1.5);
  end
  
Max_All(:,1) = max(Y);
Q3_All(:,1) = quantile(Y,0.75);
Mean_All(:,1) = mean(Y);
Median_All(:,1) = median(Y);
Q1_All(:,1) = quantile(Y,0.25);
Min_All(:,1) = min(Y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Start of Simulation

for i=1:NP;
    if strcmp(H_Dist,'Exponential') 
       H_matrix = exprnd(theta,NA,1);
     
     elseif strcmp(H_Dist,'Gamma') 
       H_matrix = gamrnd(theta(1),theta(2),NA,1);
      
     else  %Longnorm(2,1)
       H_matrix = lognrnd(mu,sigma,NA,1);
    end

   for j=1:NA;
   D(j,:) = Sigma_Fun(Sigma_Type,Y(j,:));
   end
 YT = D.*Y;
  
 Y = YT;
 idx = (YT==0);
 Y(idx) = H_matrix(idx);
 
 Max_All(:,1+i) = max(Y);
 Q3_All(:,1+i) = quantile(Y,0.75);
 Mean_All(:,1+i) = mean(Y);
 Median_All(:,1+i) = median(Y);
 Q1_All(:,1+i) = quantile(Y,0.25);
 Min_All(:,1+i) = min(Y);
end

fname = sprintf('GDist_%s - HDist_%s - Sigma_%s.mat',G_Dist,H_Dist,Sigma_Type);
save(fname,'G_Dist','H_Dist','Sigma_Type','H_Mean','H_Median','Max_All','Q3_All','Mean_All','Median_All','Q1_All','Min_All');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Creating Graphs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Graph == 1
%%%%%
%Q3 Mean Median Q1 Plot

%Graph important points on same plot
plot1 = plot(n,Q3_All,n,Mean_All,n,Median_All,n,Q1_All);
set(plot1(1),'DisplayName','Q3');
set(plot1(2),'DisplayName','Mean');
set(plot1(3),'DisplayName','Median');
set(plot1(4),'DisplayName','Q1');

%Create labels
xlabel('Periods');
ylabel('Dollars');

fig1name = sprintf('Q3_Mean_Median_Q1-GDist_%s-HDist_%s-Sigma_%s.fig',G_Dist,H_Dist,Sigma_Type);
savefig(fig1name);

%%%%%
%Median vs H Median Plot
hmedian=H_Median.*ones(1,NP+1);

%Graph curves on same plot
plot1 = plot(n,Median_All,n,hmedian);
set(plot1(1),'DisplayName','G_t(c)');
set(plot1(2),'LineWidth',2,'DisplayName','H(c)');

%Create labels
xlabel('Periods');
ylabel('Dollars');

fig2name = sprintf('G_Median-h_Median-GDist_%s-HDist_%s-Sigma_%s.fig',G_Dist,H_Dist,Sigma_Type);
savefig(fig2name);

else %Graph == 0
    Graph = 0;
end