%Garrett Senney & Jason Blevins
%Dynamic Search Model for Multiple Periods
%Simulating Selection Bias Worker Script
%Last Updated on May 13, 2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Initialize RNG Seed
rand('seed', 12345678);

%Initializing matrices for storage
Min_All = zeros(1,NP+1);
Max_All = zeros(1,NP+1);
Mean_All = zeros(1,NP+1);
Q10_All = zeros(1,NP+1);
Q20_All = zeros(1,NP+1);
Q30_All = zeros(1,NP+1);
Q40_All = zeros(1,NP+1);
Q50_All = zeros(1,NP+1);
Q60_All = zeros(1,NP+1);
Q70_All = zeros(1,NP+1);
Q80_All = zeros(1,NP+1);
Q90_All = zeros(1,NP+1);

%Generate the starting distribution of G_{t}(c)
if strcmp(G_Dist,'Gamma15')
    theta_g = [15,0.2];
    Y = gamrnd(theta_g(1),theta_g(2),NA,1);

elseif strcmp(G_Dist,'Gamma25')
    theta_g = [25,0.2];
    Y = gamrnd(theta_g(1),theta_g(2),NA,1);

elseif strcmp(G_Dist,'Lognormal1.5')
    mu = 1.5;
    sigma = 1;
    Y = lognrnd(mu,sigma,NA,1);

elseif strcmp(G_Dist,'Lognormal5')
    mu = 5;
    sigma = 1;
    Y = lognrnd(mu,sigma,NA,1);
    
elseif strcmp(G_Dist,'Uniform')
    Y = 25*rand(NA,1);

elseif strcmp(G_Dist,'Exponential4.1')
    Y = exprnd(4.1,NA,1);

else %Empirical CDF from last period of data (Amemiya)
    beta = [-2, 24];
    Y = beta(1)+beta(2)*rand(NA,1);
end

%Generate the entry distribution of H(c) 
if strcmp(H_Dist,'Exponential') %Exponential distribution with estimated mean
    theta = 4;
    H_Mean = 4;
    H_Q10 = expinv(0.1, theta);
    H_Q20 = expinv(0.2, theta);
    H_Q30 = expinv(0.3, theta);
    H_Q40 = expinv(0.4, theta);
    H_Q50 = expinv(0.5, theta);
    H_Q60 = expinv(0.6, theta);
    H_Q70 = expinv(0.7, theta);
    H_Q80 = expinv(0.8, theta);
    H_Q90 = expinv(0.9, theta);

elseif strcmp(H_Dist,'Gamma') %Gamma distribution 
    theta = [25, 0.2];
    H_Mean = 5;
    H_Q10 = gaminv(0.1, theta(1), theta(2));
    H_Q20 = gaminv(0.2, theta(1), theta(2));
    H_Q30 = gaminv(0.3, theta(1), theta(2));
    H_Q40 = gaminv(0.4, theta(1), theta(2));
    H_Q50 = gaminv(0.5, theta(1), theta(2));
    H_Q60 = gaminv(0.6, theta(1), theta(2));
    H_Q70 = gaminv(0.7, theta(1), theta(2));
    H_Q80 = gaminv(0.8, theta(1), theta(2));
    H_Q90 = gaminv(0.9, theta(1), theta(2));

else  %Longnormal distribution
    theta = [ 1.5, 1 ];
    HDist = 'Lognormal';
    H_Mean = exp(2);
    H_Q10 = logninv(0.1, theta(1), theta(2));
    H_Q20 = logninv(0.2, theta(1), theta(2));
    H_Q30 = logninv(0.3, theta(1), theta(2));
    H_Q40 = logninv(0.4, theta(1), theta(2));
    H_Q50 = logninv(0.5, theta(1), theta(2));
    H_Q60 = logninv(0.6, theta(1), theta(2));
    H_Q70 = logninv(0.7, theta(1), theta(2));
    H_Q80 = logninv(0.8, theta(1), theta(2));
    H_Q90 = logninv(0.9, theta(1), theta(2));
end

Min_All(1) = min(Y);
Max_All(1) = max(Y);
Mean_All(1) = mean(Y);
Q10_All(1) = quantile(Y,0.10);
Q20_All(1) = quantile(Y,0.20);
Q30_All(1) = quantile(Y,0.30);
Q40_All(1) = quantile(Y,0.40);
Q50_All(1) = quantile(Y,0.50);
Q60_All(1) = quantile(Y,0.60);
Q70_All(1) = quantile(Y,0.70);
Q80_All(1) = quantile(Y,0.80);
Q90_All(1) = quantile(Y,0.90);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Start of Simulation

for i=1:NP;
    if strcmp(H_Dist,'Exponential') 
        H_matrix = exprnd(theta,NA,1);
        
    elseif strcmp(H_Dist,'Gamma') 
        H_matrix = gamrnd(theta(1),theta(2),NA,1);
        
    else  %Longnorm(2,1)
        H_matrix = lognrnd(theta(1),theta(2),NA,1);
    end

    for j=1:NA;
        % not purchase = 1, purchase = 0
        D(j,:) = Sigma_Fun(Sigma_Type,Y(j,:));
    end
    YT = D.*Y;
    
    Y = YT;
    idx = (YT==0);
    Y(idx) = H_matrix(idx);
    
    Min_All(1+i) = min(Y);
    Max_All(1+i) = max(Y);
    Mean_All(1+i) = mean(Y);
    Q10_All(1+i) = quantile(Y,0.10);
    Q20_All(1+i) = quantile(Y,0.20);
    Q30_All(1+i) = quantile(Y,0.30);
    Q40_All(1+i) = quantile(Y,0.40);
    Q50_All(1+i) = quantile(Y,0.50);
    Q60_All(1+i) = quantile(Y,0.60);
    Q70_All(1+i) = quantile(Y,0.70);
    Q80_All(1+i) = quantile(Y,0.80);
    Q90_All(1+i) = quantile(Y,0.90);
end

fname = sprintf('sim%d.mat',spec);
save(fname,'spec','G_Dist','H_Dist','Sigma_Type','H_Mean','H_Q10','H_Q20','H_Q30','H_Q40','H_Q50','H_Q60','H_Q70','H_Q80','H_Q90','Min_All','Max_All','Mean_All','Q10_All','Q20_All','Q30_All','Q40_All','Q50_All','Q60_All','Q70_All','Q80_All','Q90_All');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Creating Graphs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%
% Quantile bias
Q10_Bias = Q10_All - H_Q10.*ones(1,NP+1);
Q20_Bias = Q20_All - H_Q20.*ones(1,NP+1);
Q30_Bias = Q30_All - H_Q30.*ones(1,NP+1);
Q40_Bias = Q40_All - H_Q40.*ones(1,NP+1);
Q50_Bias = Q50_All - H_Q50.*ones(1,NP+1);
Q60_Bias = Q60_All - H_Q60.*ones(1,NP+1);
Q70_Bias = Q70_All - H_Q70.*ones(1,NP+1);
Q80_Bias = Q80_All - H_Q80.*ones(1,NP+1);
Q90_Bias = Q90_All - H_Q90.*ones(1,NP+1);

fh = figure(spec);
set(fh, ...
    'PaperUnits', 'inches', ...
    'PaperSize', [5.01 3.01], ...
    'PaperPosition', [0.01 0.01 5.0 3.0], ...
    'color', 'white');

h10 = plot(Q10_Bias(2:NP+1));
hold on
h20 = plot(Q20_Bias(2:NP+1));
h30 = plot(Q30_Bias(2:NP+1));
h40 = plot(Q40_Bias(2:NP+1));
h50 = plot(Q50_Bias(2:NP+1));
h60 = plot(Q60_Bias(2:NP+1));
h70 = plot(Q70_Bias(2:NP+1));
h80 = plot(Q80_Bias(2:NP+1));
h90 = plot(Q90_Bias(2:NP+1));

set(h10, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h20, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h30, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h40, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h60, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h70, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h80, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');
set(h90, 'LineStyle', '--', 'LineWidth', 1.0, 'Color', 'Black');

c_scarlet = [ 187/255, 0, 0 ];
set(h50, 'LineStyle', '-', 'LineWidth', 2.0, 'Color', c_scarlet);

ylabel('Bias (USD)');
xlabel('Period');

figname = sprintf('sim%d-bias',spec);
print('-dpdf',[figname,'.pdf']);
savefig([figname,'.fig']);
clf
