function [loglik, g] = loglik(qmat, n, v, p, plow)

% This function computes the log-likelihood function
% Written by Matthijs R. Wildenbeest, October 2007.
% Modified by Jason R. Blevins for thread safety, April 2014, and for
% vectorization, April 2016.

options = optimset('TolFun', 1e-12, 'Display', 'off');

% Precalculate sequences used below
nseq = (1:n)';
nseq1 = [ 0, 1:n-1 ]';
nseq2 = [ 0, 0, 1:n-2 ]';
nseq3 = [ 0, 0, 0, 1:n-3 ]';
nseq4 = [ 0, 0, 0, 0, 1:n-4 ]';

% calculate unit cost r
ksum = sum(nseq .* qmat);
r = (plow*ksum - v*qmat(1)) / (ksum - qmat(1));

% calculate density function f(p) (see equation (9))
np = size(p,1);
F = zeros(1, np);
dens = zeros(1, np);
for j = 1:np
    f_func = @(G)f(G, v, p(j), plow, n, qmat);
    % compute F(p) that solves equilibrium condition
    F(j) = fzero(f_func, 0.9, options);
    ksum = sum(nseq .* qmat .* (1-F(j)).^nseq1);
    ksum2 = sum(nseq1 .* nseq .* qmat .* (1-F(j)).^nseq2);
    dens(j) = ksum/((p(j)-r)*ksum2); % f(p)
end

loglik = (-1)*(log(dens));
loglik = sum(loglik); % log-likelihood function

% Leave out first term of sequences (sum over 2:n).
nseq(1) = 0;

% Calculate the analytical gradient
nq_cur = nseq .* qmat;
ksum = sum(nq_cur);
F1 = repmat(1-F, n, 1);
ksum2 = (F1.^repmat(nseq1, 1, np))' * nq_cur;
nq_cur = nq_cur .* nseq1;
ksum3 = -(F1.^repmat(nseq2, 1, np))' * nq_cur;
nq_cur = nq_cur .* nseq2;
ksum4 = (F1.^repmat(nseq3, 1, np))' * nq_cur;
nq_cur = nq_cur .* nseq3;
ksum5 = -(F1.^repmat(nseq4, 1, np))' * nq_cur;

densq = zeros(size(p,1), n);
densq(:,1) = ((p - plow).*ksum + (plow - v).*ksum2 + (((p - v).*ksum + (-plow + v).*ksum2).*(-ksum3.^2 + (qmat(1) + ksum2).*ksum4))./ksum3.^2)./(((plow - v).*qmat(1) + (-p + plow).*ksum).*(qmat(1) + ksum2));
for kk = 2:n
    densq(:,kk) = ((kk.*((1-kk).*(1-F').^(kk-2).*(p - plow - ((plow - v).*qmat(1))./ksum).*(qmat(1) + ksum2) + -1*(1 - F').^(kk-1).*(p - plow - ((plow - v).*qmat(1))./ksum).*ksum3 + ((plow - v).*qmat(1).*(qmat(1)+ksum2).*ksum3)./ksum.^2))./ksum3 + (-kk.*(1-F').^(kk-1).*(p - plow - ((plow - v).*qmat(1))./ksum) - (kk.*(plow - v).*qmat(1).*ksum2)./ksum.^2).*(-1 + ((qmat(1)+ ksum2).*ksum4)./ksum3.^2))./((p - plow - ((plow - v).*qmat(1))./ksum).*(qmat(1) +ksum2));
end

g = sum(densq);
